@@ -20,7 +20,10 @@ from flask import Flask, render_template, request, url_for, flash, redirect, jso
 from flask_cors import CORS
 from werkzeug.exceptions import abort
 
-import eisenradio.lib.eisen_radio as eR
+try:
+    import lib.eisen_radio as eR
+except ImportError:
+    import eisenradio.lib.eisen_radio as eR
 import shutil
 
 app = Flask(__name__)
@@ -36,10 +39,10 @@ first_run_index = True
 listen_btn = False
 status_listen_btn_dict = {}  # {table id 15: 1 } on
 status_record_btn_dict = {}
-radio_pic_dict = {}
+# radio_pic_dict = {}
 
 last_btn_id = None  # current button pressed, or btn predecessor / to redraw, if next is pressed / first is null->err
-last_url = None
+listen_last_url = None
 combo_master_timer = 0
 progress_master_percent = 0
 
@@ -48,6 +51,10 @@ progress_master_percent = 0
 def index():
     global first_run_index
     global combo_master_timer
+    global listen_last_url
+    global current_station
+
+    current_station = ''
 
     conn = get_db_connection()
     posts = conn.execute('SELECT * FROM posts').fetchall()
@@ -72,11 +79,17 @@ def index():
         json_post = index_posts_clicked(post_request)
         return json_post
 
+    for key_table_id, val in status_listen_btn_dict.items():
+        if val:
+            current_station = status_read_status_set(False, 'posts', 'title', key_table_id)
+
     return render_template('index.html',
                            posts=posts,
                            combo_master_timer=combo_master_timer,
                            status_listen_btn_dict=status_listen_btn_dict,
-                           status_record_btn_dict=status_record_btn_dict)
+                           status_record_btn_dict=status_record_btn_dict,
+                           current_station=current_station,
+                           listen_last_url=listen_last_url)
 
 
 @app.route('/index_posts_combo', methods=['POST'])
@@ -97,7 +110,7 @@ def index_posts_clicked(post_request):
     # invoke m3u check function, this version does not have a relay server
     global listen_btn
     global last_btn_id
-    global last_url
+    global listen_last_url
 
     pay_load = post_request['data']
     button_list = pay_load.split('_')
@@ -106,35 +119,31 @@ def index_posts_clicked(post_request):
 
     if button == 'Listen':  # turn values, update button status dict
 
-        if status_listen_btn_dict[int(table_id)]:
+        if status_listen_btn_dict[int(table_id)]:   # button was down
             status_listen_btn_dict[int(table_id)] = 0
-            EisenApp.dispatch_master(int(table_id), 'Listen', 0)  # now idle
-            # ask GIni for url also 'playlist'
-            if not last_btn_id == table_id:  # auto pressed
-                return jsonify(
-                    {'result': 'auto_click_jquery'})
+            EisenApp.dispatch_master(int(table_id), 'Listen', 0)
+            if not last_btn_id == table_id:
+                return jsonify({'result': 'auto_click was here. no result needed. nada'})
         else:
-            status_listen_btn_dict[int(table_id)] = 1
-            if last_btn_id is None:
-                last_btn_id = table_id
+            status_listen_btn_dict[int(table_id)] = 1   # button just pressed, register state, new station
 
             if not last_btn_id == table_id:  # other btn pressed
                 if listen_btn:  # was playing before actual btn
                     switch_btn = last_btn_id  # press abandoned btn, play new url
                     last_btn_id = table_id
-                    str_url = query_radio_url(table_id)  # radio url
-                    last_url = str_url
+                    listen_last_url = query_radio_url(table_id)  # radio url
                     EisenApp.dispatch_master(int(table_id), 'Listen', 1)
+                    current_station = status_read_status_set(False, 'posts', 'title', table_id)
+                    # trigger auto_click
                     return jsonify(
                         {'former_button_to_switch': switch_btn,
-                         'query_url': str_url,
+                         'query_url': listen_last_url,
                          'if not last_btn_id == table_id': '------ last_btn_id --------',
-                         'result': 'activate_audio'})
+                         'result': 'activate_audio', 'table_ident': current_station})
 
             EisenApp.dispatch_master(int(table_id), 'Listen', 1)
 
-        str_url = query_radio_url(table_id)  # radio url
-        last_url = str_url
+        listen_last_url = query_radio_url(table_id)  # radio url
         last_btn_id = table_id
 
         listen_btn = False
@@ -145,12 +154,13 @@ def index_posts_clicked(post_request):
 
         # print(status_listen_btn_dict)
         if listen_btn:
+            current_station = status_read_status_set(False, 'posts', 'title', table_id)
             return jsonify(
-                {'former_button_to_switch': False, 'buttons': button, 'query_url': str_url,
-                 'result': 'activate_audio'})
+                {'former_button_to_switch': False, 'buttons': button, 'query_url': listen_last_url,
+                 'result': 'activate_audio', 'table_ident': current_station})
         else:
             return jsonify(
-                {'former_button_to_switch': False, 'buttons': button, 'query_url': str_url,
+                {'former_button_to_switch': False, 'buttons': button, 'query_url': listen_last_url,
                  'result': 'deactivate_audio'})
 
     if button == 'Record':
@@ -749,6 +759,7 @@ def open_with_default(path):
 
 
 def open_browser():
+    print('\n\t---> Use url "http://localhost:5050/" to connect your Browser. <---\n')
     is_enabled = status_read_status_set(False, 'eisen_intern', 'browser_open', '1')
 
     if is_enabled:
@@ -760,11 +771,29 @@ def open_browser():
 
 
 def main():
-    get_environment()
-    open_browser()
+    try:
+        if os.environ["DOCKER"]:
+            print('\n\tEisenRadio App in Docker Container\n')
+            print('\tUse url "http://localhost:5050/" to connect your Browser.\n')
+    except KeyError:
+        get_environment()
+        open_browser()
 
 
+class Radio:
+    dict_stations = {}  # keys are used as variables, value is instance of Radio class
 
+    def __init__(self, name, record, listen, error, error_text, stream_text, listen_history, last_button_id,
+                 this_radio_id):
+        self.name = name
+        self.record = record  # False
+        self.listen = listen  # False
+        self.error = error  # False
+        self.error_text = error_text  # None
+        self.stream_text = stream_text  # None
+        self.listen_history = listen_history  # not the first button pressed, False
+        self.last_button_id = last_button_id  # int table_id, None
+        self.this_radio_id = this_radio_id
 if __name__ == "__main__":
     main()
     app.run(host='localhost', port='5050', threaded=True, debug=True, use_reloader=False)
